@@ -87,6 +87,7 @@ class GAlearner:
                  custom_transformer_pipeline=None,
                  combine_with_existing_representation = False,
                  conceptnet_url = "https://s3.amazonaws.com/conceptnet/downloads/2019/edges/conceptnet-assertions-5.7.0.csv.gz",
+                 default_importance = 0.05,
                  verbose = 1):
         """
         The object initialization method
@@ -107,6 +108,7 @@ class GAlearner:
         :param classifier: custom classifier. If none, linear learners are used.
         :param classifier_hyperparameters: The space to be optimized w.r.t. the classifier param.
         :param conceptnet_url: URL of the conceptnet used.
+        :param default_importance: Minimum possible initial weight.
         """
         
         logo = """
@@ -147,9 +149,11 @@ class GAlearner:
 
         self.verbose = verbose
         if self.verbose: print(logo)
+        self.default_importance = default_importance
         
         if self.verbose: logging.info("Instantiated the evolution-based learner.")
         self.scoring_metric = scoring_metric
+
         self.representation_type = representation_type
         self.custom_transformer_pipeline = custom_transformer_pipeline
         self.combine_with_existing_representation = combine_with_existing_representation
@@ -278,6 +282,13 @@ class GAlearner:
             "Loaded a dataset of {} texts with {} unique labels.".format(
                 self.train_seq.shape[0], len(set(train_targets))))
 
+        if self.scoring_metric is None:
+            if self.unique_labels > 2:
+                self.scoring_metric = "f1_macro"
+
+            else:
+                self.scoring_metric = "f1"
+
     def update_global_feature_importances(self):
         """
         Aggregate feature importances across top learners to obtain the final ranking.
@@ -415,7 +426,7 @@ class GAlearner:
             noise = np.random.uniform(low=0.95,
                                       high=1.05,
                                       size=self.weight_params)
-            generic_individual = generic_individual * noise + 0.001
+            generic_individual = generic_individual * noise + self.default_importance
             ind[:] = np.abs(generic_individual)
 
     def apply_weights(self,
@@ -495,14 +506,7 @@ class GAlearner:
         else:
             svc = self.classifier
 
-        if self.scoring_metric is None:
-            if self.unique_labels > 2:
-                performance_score = "f1_macro"
-
-            else:
-                performance_score = "f1"
-        else:
-            performance_score = self.scoring_metric
+        performance_score = self.scoring_metric
 
         if final_run:
             clf = GridSearchCV(svc,
@@ -761,7 +765,7 @@ class GAlearner:
             report.append(str(fn) + "  " + str(np.round(imp, 2)))
 
         report.append("-" * 60)
-        report.append("Max F1: {}".format(max_f1))
+        report.append("Max {}: {}".format(self.scoring_metric, max_f1))
 
         print("\n".join(report))
 
